[![pypi](https://img.shields.io/pypi/v/lnschema_core?color=%2334D058&label=pypi%20package)](https://pypi.org/project/lnschema_core)

# lnschema-core: Data objects & data lineage (`yvzi`)

Core schema module for tracking data lineage.

It is built with [SQLModel](https://sqlmodel.tiangolo.com/), a shallow wrapper that unifies [SQLAlchemy](https://www.sqlalchemy.org/) & [Pydantic](https://pydantic-docs.helpmanual.io/).
